#!/usr/bin/python

import jppy
import mx.DateTime

env = jppy.environment.Environment()
memos = env.memoList

try:
    cat = memos.getCategories().index("Personal")
except ValueError, e:
    cat = 0

fn = "%s.txt" % mx.DateTime.now().date

o = open(fn,"a")
for m in memos.records(categories=[cat]):
    o.write("-----------------------------------\n")
    o.write(m['text'])
    #memos.delete(m)
    o.write("\n")

o.close()

